@@ -2,6 +2,7 @@
 # SPDX-License-Identifier: Apache-2.0
 
 import click
+import yaml
 
 from servicecatalog_puppet import cli_commands
 
@@ -48,13 +49,15 @@ def bootstrap_spoke(puppet_account_id):
 
 @cli.command()
 @click.argument('branch-name')
-def bootstrap_branch(branch_name):
-    cli_commands.bootstrap_branch(branch_name)
+@click.option('--with-manual-approvals/--with-no-manual-approvals', default=False)
+def bootstrap_branch(branch_name, with_manual_approvals):
+    cli_commands.bootstrap_branch(branch_name, with_manual_approvals)
 
 
 @cli.command()
-def bootstrap():
-    cli_commands.bootstrap()
+@click.option('--with-manual-approvals/--with-no-manual-approvals', default=False)
+def bootstrap(with_manual_approvals):
+    cli_commands.bootstrap(with_manual_approvals)
 
 
 @cli.command()
@@ -65,9 +68,10 @@ def seed(complexity, p):
 
 
 @cli.command()
-@click.argument('f', type=click.File())
-def list_launches(f):
-    cli_commands.list_launches(f)
+@click.argument('expanded_manifest', type=click.File())
+@click.option('--format','-f', type=click.Choice(['table', 'json']),default='table')
+def list_launches(expanded_manifest, format):
+    cli_commands.list_launches(expanded_manifest, format)
 
 
 @cli.command()
@@ -130,5 +134,39 @@ def import_product_set(f, name, portfolio_name):
     cli_commands.import_product_set(f, name, portfolio_name)
 
 
+@cli.command()
+@click.argument('account_or_ou_file_path', type=click.File())
+def add_to_accounts(account_or_ou_file_path):
+    cli_commands.add_to_accounts(
+        yaml.safe_load(account_or_ou_file_path)
+    )
+
+
+@cli.command()
+@click.argument('account_id_or_ou_id_or_ou_path')
+def remove_from_accounts(account_id_or_ou_id_or_ou_path):
+    cli_commands.remove_from_accounts(account_id_or_ou_id_or_ou_path)
+
+
+@cli.command()
+@click.argument('launch_file_path', type=click.File())
+def add_to_launches(launch_name, launch_file_path):
+    cli_commands.add_to_launches(
+        launch_name, yaml.safe_load(launch_file_path)
+    )
+
+
+@cli.command()
+@click.argument('launch_name')
+def remove_from_launches(launch_name):
+    cli_commands.remove_from_launches(launch_name)
+
+
+@cli.command()
+@click.argument('f', type=click.File())
+def reset_provisioned_product_owner(f):
+    cli_commands.reset_provisioned_product_owner(f)
+
+
 if __name__ == "__main__":
     cli()
