@@ -150,7 +150,7 @@ def set_regions_for_deployment_map(deployment_map, section):
                 for a in launch_details.get('deploy_to').get('accounts'):
                     if a.get('account_id') == account_id:
                         regions = a.get('regions')
-                        if regions == "enabled":
+                        if regions in ["enabled", "regions_enabled"]:
                             regions = account_details.get('regions_enabled')
                         elif regions == "default_region" or regions is None:
                             regions = account_details.get('default_region')
@@ -173,7 +173,7 @@ def set_regions_for_deployment_map(deployment_map, section):
                 for t in launch_details.get('deploy_to').get('tags'):
                     if t.get('tag') in account_details.get('tags'):
                         regions = t.get('regions')
-                        if regions == "enabled":
+                        if regions in ["enabled", "regions_enabled"]:
                             regions = account_details.get('regions_enabled')
                         elif regions == "default_region" or regions is None:
                             regions = account_details.get('default_region')
@@ -456,7 +456,7 @@ def deploy_spoke_local_portfolios(manifest, launch_tasks):
         for launch_name, launch_details in deployments_for_account.get(section).items():
             for region_name in launch_details.get('regions'):
 
-                depends_on = launch_details.get('depends_on')
+                depends_on = launch_details.get('depends_on', [])
                 dependencies = []
                 for dependency in depends_on:
                     for task_uid, task in launch_tasks.items():
