@@ -25,7 +25,6 @@ from servicecatalog_puppet import luigi_tasks_and_targets
 from servicecatalog_puppet import manifest_utils
 from servicecatalog_puppet import aws
 
-
 from servicecatalog_puppet import asset_helpers
 from servicecatalog_puppet import constants
 
@@ -80,6 +79,24 @@ def dry_run(f):
     cli_command_helpers.run_tasks_for_dry_run(tasks_to_run)
 
 
+def reset_provisioned_product_owner(f):
+    manifest = manifest_utils.load(f)
+
+    launch_tasks = {}
+    tasks_to_run = []
+
+    all_launch_tasks = cli_command_helpers.deploy_launches(manifest)
+    launch_tasks.update(all_launch_tasks)
+
+    for task in cli_command_helpers.wire_dependencies(launch_tasks):
+        task_status = task.get('status')
+        del task['status']
+        if task_status == constants.PROVISIONED:
+            tasks_to_run.append(luigi_tasks_and_targets.ResetProvisionedProductOwnerTask(**task))
+
+    cli_command_helpers.run_tasks(tasks_to_run)
+
+
 def deploy(f, single_account):
     manifest = manifest_utils.load(f)
 
@@ -131,20 +148,28 @@ def bootstrap_spoke_as(puppet_account_id, iam_role_arns):
             'cloudformation',
             cross_accounts
     ) as cloudformation:
-        cli_command_helpers._do_bootstrap_spoke(puppet_account_id, cloudformation, cli_command_helpers.get_puppet_version())
+        cli_command_helpers._do_bootstrap_spoke(puppet_account_id, cloudformation,
+                                                cli_command_helpers.get_puppet_version())
 
 
 def bootstrap_spoke(puppet_account_id):
     with betterboto_client.ClientContextManager('cloudformation') as cloudformation:
-        cli_command_helpers._do_bootstrap_spoke(puppet_account_id, cloudformation, cli_command_helpers.get_puppet_version())
+        cli_command_helpers._do_bootstrap_spoke(puppet_account_id, cloudformation,
+                                                cli_command_helpers.get_puppet_version())
 
 
-def bootstrap_branch(branch_name):
-    cli_command_helpers._do_bootstrap("https://github.com/awslabs/aws-service-catalog-puppet/archive/{}.zip".format(branch_name))
+def bootstrap_branch(branch_name, with_manual_approvals):
+    cli_command_helpers._do_bootstrap(
+        "https://github.com/awslabs/aws-service-catalog-puppet/archive/{}.zip".format(branch_name),
+        with_manual_approvals,
+    )
 
 
-def bootstrap():
-    cli_command_helpers._do_bootstrap(cli_command_helpers.get_puppet_version())
+def bootstrap(with_manual_approvals):
+    cli_command_helpers._do_bootstrap(
+        cli_command_helpers.get_puppet_version(),
+        with_manual_approvals,
+    )
 
 
 def seed(complexity, p):
@@ -157,9 +182,10 @@ def seed(complexity, p):
     )
 
 
-def list_launches(f):
+def list_launches(f, format):
     manifest = manifest_utils.load(f)
-    click.echo("Getting details from your account...")
+    if format == "table":
+        click.echo("Getting details from your account...")
     ALL_REGIONS = cli_command_helpers.get_regions(os.environ.get("AWS_DEFAULT_REGION"))
     deployment_map = manifest_utils.build_deployment_map(manifest, constants.LAUNCHES)
     account_ids = [a.get('account_id') for a in manifest.get('accounts')]
@@ -225,43 +251,65 @@ def list_launches(f):
                                     indent=4, default=str
                                 ))
 
-    table = [
-        ['account_id', 'region', 'launch', 'portfolio', 'product', 'expected_version', 'actual_version', 'active',
-         'status']
-    ]
+    results = {}
     for account_id, details in deployment_map.items():
         for launch_name, launch in details.get(constants.LAUNCHES, {}).items():
             if deployments.get(account_id, {}).get(constants.LAUNCHES, {}).get(launch_name) is None:
                 pass
             else:
                 for region, regional_details in deployments[account_id][constants.LAUNCHES][launch_name].items():
-                    if regional_details.get('status') == "AVAILABLE":
-                        status = Color("{green}" + regional_details.get('status') + "{/green}")
-                    else:
-                        status = Color("{red}" + regional_details.get('status') + "{/red}")
-                    expected_version = launch.get('version')
-                    actual_version = regional_details.get('version')
-                    if expected_version == actual_version:
-                        actual_version = Color("{green}" + actual_version + "{/green}")
-                    else:
-                        actual_version = Color("{red}" + actual_version + "{/red}")
-                    active = regional_details.get('active')
-                    if active:
-                        active = Color("{green}" + str(active) + "{/green}")
-                    else:
-                        active = Color("{orange}" + str(active) + "{/orange}")
-                    table.append([
-                        account_id,
-                        region,
-                        launch_name,
-                        regional_details.get('portfolio'),
-                        regional_details.get('product'),
-                        expected_version,
-                        actual_version,
-                        active,
-                        status,
-                    ])
-    click.echo(terminaltables.AsciiTable(table).table)
+                    results[f"{account_id}_{region}_{launch_name}"] = {
+                        'account_id': account_id,
+                        'region': region,
+                        'launch': launch_name,
+                        'portfolio': regional_details.get('portfolio'),
+                        'product': regional_details.get('product'),
+                        'expected_version': launch.get('version'),
+                        'actual_version': regional_details.get('version'),
+                        'active': regional_details.get('active'),
+                        'status': regional_details.get('status'),
+                    }
+
+    if format == "table":
+        table = [
+            [
+                'account_id',
+                'region',
+                'launch',
+                'portfolio',
+                'product',
+                'expected_version',
+                'actual_version',
+                'active',
+                'status',
+            ]
+        ]
+
+        for result in results.values():
+            table.append([
+                result.get('account_id'),
+                result.get('region'),
+                result.get('launch'),
+                result.get('portfolio'),
+                result.get('product'),
+                result.get('expected_version'),
+                Color("{green}" + result.get('actual_version') + "{/green}") if result.get('actual_version') == result.get('expected_version') else Color("{red}" + result.get('actual_version') + "{/red}"),
+                Color("{green}" + str(result.get('active')) + "{/green}") if result.get('active') else Color("{red}" + str(result.get('active')) + "{/red}"),
+                Color("{green}" + result.get('status') + "{/green}") if result.get('status') == "AVAILABLE" else Color("{red}" + result.get('status') + "{/red}")
+            ])
+        click.echo(terminaltables.AsciiTable(table).table)
+
+    elif format == "json":
+        click.echo(
+            json.dumps(
+                results,
+                indent=4,
+                default=str,
+            )
+        )
+
+    else:
+        raise Exception(f"Unsupported format: {format}")
 
 
 def expand(f):
@@ -483,3 +531,60 @@ def import_product_set(f, name, portfolio_name):
         f.write(
             yaml.safe_dump(manifest)
         )
+
+
+def get_manifest():
+    with betterboto_client.ClientContextManager('codecommit') as codecommit:
+        content = codecommit.get_file(
+            repositoryName=constants.SERVICE_CATALOG_PUPPET_REPO_NAME,
+            filePath="manifest.yaml",
+        ).get('fileContent')
+        return yaml.safe_load(content)
+
+
+def save_manifest(manifest):
+    with betterboto_client.ClientContextManager('codecommit') as codecommit:
+        parent_commit_id = codecommit.get_branch(
+            repositoryName=constants.SERVICE_CATALOG_PUPPET_REPO_NAME,
+            branchName='master',
+        ).get('branch').get('commitId')
+        codecommit.put_file(
+            repositoryName=constants.SERVICE_CATALOG_PUPPET_REPO_NAME,
+            branchName='master',
+            fileContent=yaml.safe_dump(manifest),
+            parentCommitId=parent_commit_id,
+            commitMessage="Auto generated commit",
+            filePath=f"manifest.yaml",
+        )
+
+
+def add_to_accounts(account_or_ou):
+    manifest = get_manifest()
+    manifest.get('accounts').append(account_or_ou)
+    save_manifest(manifest)
+
+
+def remove_from_accounts(account_id_or_ou_id_or_ou_path):
+    manifest = get_manifest()
+    for account in manifest.get('accounts', []):
+        if account.get('account_id', '') == account_id_or_ou_id_or_ou_path:
+            manifest.get('accounts').remove(account)
+            return save_manifest(manifest)
+        elif account.get('ou', '') == account_id_or_ou_id_or_ou_path:
+            manifest.get('accounts').remove(account)
+            return save_manifest(manifest)
+    raise Exception(f"Did not remove {account_id_or_ou_id_or_ou_path}")
+
+
+def add_to_launches(launch_name, launch):
+    manifest = get_manifest()
+    launches = manifest.get('launches', {})
+    launches[launch_name] = launch
+    manifest['launches'] = launches
+    save_manifest(manifest)
+
+
+def remove_from_launches(launch_name):
+    manifest = get_manifest()
+    del manifest.get('launches')[launch_name]
+    save_manifest(manifest)
